@@ -1,11 +1,12 @@
 from django import http, shortcuts, template
 from django.conf import settings
-from newscenter import models
-from django.views.generic import date_based
+from django.views.generic import YearArchiveView, MonthArchiveView
 from django.contrib.sites.models import Site
 from django.core.paginator import Paginator, InvalidPage, EmptyPage
 from django.shortcuts import get_object_or_404
 
+from newscenter import models
+
 def article_detail(request, newsroom, year, month, slug):
     request,
     year = year,
@@ -16,28 +17,36 @@ def article_detail(request, newsroom, year, month, slug):
         'newscenter/article_detail.html', locals(),
         context_instance=template.RequestContext(request))
 
-def archive_year(request, newsroom, year):
-    room = models.Newsroom.objects.get(slug__exact=newsroom)
-    return date_based.archive_year(
-        request,
-        year = year,
-        date_field = 'release_date',
-        make_object_list = True,        
-        extra_context = {'newsroom': room},
-        queryset = models.Article.objects.get_published().filter(
-            newsroom__slug=newsroom)
-    )
-def archive_month(request, newsroom, year, month):
-    room = models.Newsroom.objects.get(slug__exact=newsroom)
-    return date_based.archive_month(
-        request,
-        year = year,
-        month = month,
-        date_field = 'release_date',
-        extra_context = {'newsroom': room},
-        queryset = models.Article.objects.get_published().filter(
-            newsroom__slug=newsroom)
-    )
+class ArchiveYear(YearArchiveView):
+    model = models.Article
+    date_field = 'release_date'
+    make_object_list = True
+
+    def get_queryset(self):
+        return models.Article.objects.get_published().filter(
+            newsroom__slug=self.kwargs['newsroom']
+        )
+
+    def get_context_data(self, *args, **kwargs):
+        ctx = super(ArchiveYear, self).get_context_data(*args, **kwargs)
+        ctx['newsroom'] = self.kwargs['newsroom']
+        return ctx        
+
+
+class ArchiveMonth(YearArchiveView):
+    model = models.Article
+    date_field = 'release_date'
+    make_object_list = True
+
+    def get_queryset(self):
+        return models.Article.objects.get_published().filter(
+            newsroom__slug=self.kwargs['newsroom']
+        )
+
+    def get_context_data(self, *args, **kwargs):
+        ctx = super(ArchiveMonth, self).get_context_data(*args, **kwargs)
+        ctx['newsroom'] = self.kwargs['newsroom']
+        return ctx        
 
 def category_detail(request, slug):
     category = models.Category.objects.get(slug__exact=slug)
